@@ -84,6 +84,11 @@ lapply_async2 <- function(x, FUN, FUN.args = list(),
     }
   }
 
+  if(inherits(callback, "formula")) {
+    penv <- parent.frame()
+    callback <- rlang::as_function(callback, env = penv)
+  }
+
   if( is.function(callback) ){
 
     callback_formals <- formals(callback)
@@ -116,17 +121,40 @@ lapply_async2 <- function(x, FUN, FUN.args = list(),
     # if(is.null(shiny::getDefaultReactiveDomain())){
 
     progressr::with_progress({
-      p <- progressr::progressor(along = x)
+      p <- progressr::progressor(steps = 2 * length(x) + 1)
 
-      f <- dipsaus::new_function2(alist(el = ), body = rlang::quo({
-        p(message = eval(!!callback_call))
-        eval(!!call)
-      }), quote_type = 'quote', env = environment())
+      f <- dipsaus::new_function2(alist(el = ), body = bquote({
+        ...msg... <- .(callback_call)
+        if(is.character(...msg...)) {
+          ...msg... <- paste(...msg..., collapse = "")
+        } else {
+          ...msg... <- deparse(el, width.cutoff = 30)
+          if(length(...msg...) > 1){
+            ...msg... <- ...msg...[[1]]
+          }
+          if(nchar(...msg...) >= 10){
+            ...msg... <- sprintf("%s...", substr(...msg..., stop = 7, start = 1))
+          }
+        }
+        p(message = sprintf("%s (started)", ...msg...), )
+        on.exit({
+          p(message = sprintf("%s (end)", ...msg...))
+        }, add = TRUE, after = TRUE)
+
+        .(call)
+
+      }), quote_type = "quote", env = environment())
+      # f <- dipsaus::new_function2(alist(el = ), body = rlang::quo({
+      #   p(message = sprintf("%s (started)", ...msg...), )
+      #   eval(!!call)
+      #   p(message = sprintf("%s (end)", ...msg...))
+      # }), quote_type = 'quote', env = environment())
       fs <- future.apply::future_lapply(x, f,
                                         future.scheduling = TRUE,
                                         future.chunk.size = future.chunk.size,
                                         future.seed = future.seed)
 
+      p("Results collected\n")
 
         # fs <- future.apply::future_lapply(x, function(el) {
         #   p(message = eval(callback_call))
